/*
This program sets up the F001 process to run on the IMS B421 TRAM. It is
referenced in the twotrams.cfs configuration file.

The f001_proc function allows the main function to start F001 as a process 
running in parallel with the application.

The first parameter to a function that is to be run as a process must be
a pointer to Process. This is so that the function can access it's process
descriptor data structure.
*/

#include <misc.h>
#include <stdlib.h>
#include <process.h>
#include <channel.h>

/* f001.h gives access to the F001 process. It is needed in all files
   which start F001 as a parallel process via the ProcPar routines */

#include <f001.h>

/* f001def.h provides various constant definitions for error codes
   and general use. You should include it if you wish to use the
   predefined constants provided therein. The f001def.h file should
   be examined for further information */

#include <f001def.h>

#define F001_STACK 0xE00

void f001_proc (Process *p, Channel *from_f001, Channel *to_f001)

  {
   /*
   The next statement prevents the compiler generating spurious error
   messages about unused variables
   */

   p = p;
   f001 (from_f001, to_f001);   
  } 

int main (void)
  
  {
   /*
   The following code starts f001_proc as a parallel process running on
   the IMS B421 TRAM. The reader should refer to the rootdemo.c file for 
   an explanation of the method by which this is done.
   */

   Channel *from_f001, *to_f001;
   Process *f001p;

   from_f001 = (Channel *) get_param (2);
   if (from_f001 == NULL)
     abort ();      

   to_f001 = (Channel *) get_param (1);
   if (to_f001 == NULL)
     abort ();      
   
   f001p = ProcAlloc (f001_proc, F001_STACK, 2, from_f001, to_f001);
   if (f001p == NULL)
     abort ();

   ProcPar (f001p, NULL);

  }

